#include "logger_task.h"

#include "usart/usart.h"
#include "encoder/encoder.h"
#include "motor_control/motor_control.h"
#include "pid/pid.h"

#include <string.h>

#define USART_BUF_SIZE			256
#define PID_KP					5.94257746859231f
#define PID_KI					(347.191257500237f * 0.005f)
#define PID_KD					0

static uint8_t usart_buf[USART_BUF_SIZE];

static void logger_task(void * params);

void logger_task_init(void)
{
   usart_init();
   encoder_init();
   rtos_task_create(logger_task, "logger", LOGGER_STACKSIZE, LOGGER_PRIORITY);
}

static void logger_task(void * params)
{
	(void) params;

	int32_t enc_val, speed_val;
	float set_val, pid_val;
	portTickType ticks;
	int i;

	pid_init(PID_KP, PID_KI, PID_KD);
	i = 0;
	while (1)
	{
		ticks = rtos_get_tick_count();

		/* set val after 100ms */
		if (i == 20) {
			i++;
			set_val = 11;
		} else if (i < 20) {
			i++;
		}

		enc_val = encoder_read();
		speed_val = motor_speed_get();

		pid_val = pid_calculate(set_val, enc_val);
		motor_speed_set((int32_t)pid_val);

		usart_buf[0] = (enc_val >> 8) & 0xFF;
		usart_buf[1] = enc_val & 0xFF;
		usart_buf[2] = speed_val & 0xFF;

		usart_send_buf(usart_buf, 3);

		rtos_delay_until(ticks, 5);
	}
}
