#ifndef GPIO_F4_H_
#define GPIO_F4_H_

#include "platform_specific.h"

/* Defines for GPIO modes of operation */
#define GPIO_MODE_INPUT       0
#define GPIO_MODE_OUTPUT      1
#define GPIO_MODE_AF          2
#define GPIO_MODE_ANALOG      3

/**
 * @brief Function sets GPIO pin mode.
 *
 * @param gpio                         Port to set.
 * @param pin                          Pin to set.
 * @param conf                         Mode to set.
 */
void gpio_mode_config(GPIO_TypeDef * gpio, int32_t pin, int32_t conf);

/**
 * @brief Function sets GPIO pin in push-pull mode.
 *
 * @param gpio                         Port to set.
 * @param pin                          Pin to set.
 */
#define gpio_otype_pp_set(gpio, pin)   gpio->OTYPER &= ~(1<<pin);

/**
 * @brief Function sets GPIO pin in open drain mode.
 *
 * @param gpio                         Port to set.
 * @param pin                          Pin to set.
 */
#define gpio_otype_od_set(gpio, pin)   gpio->OTYPER |= (1<<pin);

/* Defines for GPIO pin speed */
#define GPIO_SPEED_LOW        0
#define GPIO_SPEED_MEDIUM     1
#define GPIO_SPEED_FAST       2
#define GPIO_SPEED_HIGH       3

/**
 * @brief Function sets GPIO pin speed.
 *
 * @param gpio                         Port to set.
 * @param pin                          Pin to set.
 * @param conf                         Speed to set.
 */
void gpio_speed_config(GPIO_TypeDef * gpio, int32_t pin, int32_t conf);

/* Defines for GPIO pin pull-up, pull-down values */
#define GPIO_PUPD_NONE        0
#define GPIO_PUPD_PU          1
#define GPIO_PUPD_PD          2
#define GPIO_PUPD_RESERVED    3

/**
 * @brief Function sets GPIO pin pull-up, pull-down.
 *
 * @param gpio                         Port to set.
 * @param pin                          Pin to set.
 * @param conf                         Pull-up, pull down config to set.
 */
void gpio_pupd_config(GPIO_TypeDef * gpio, int32_t pin, int32_t conf);

/* Defines for GPIO pin alternative functions */
#define GPIO_AF_SYS           0
#define GPIO_AF_TIM1          1
#define GPIO_AF_TIM2          1
#define GPIO_AF_TIM3          2
#define GPIO_AF_TIM4          2
#define GPIO_AF_TIM5          2
#define GPIO_AF_TIM8          3
#define GPIO_AF_TIM9          3
#define GPIO_AF_TIM10         3
#define GPIO_AF_TIM11         3
#define GPIO_AF_I2C1          4
#define GPIO_AF_I2C2          4
#define GPIO_AF_I2C3          4
#define GPIO_AF_SPI1          5
#define GPIO_AF_SPI2          5
#define GPIO_AF_I2S2          5
#define GPIO_AF_I2S2EXT       5
#define GPIO_AF_SPI3          6
#define GPIO_AF_I2SEXT        6
#define GPIO_AF_I2S3          6
#define GPIO_AF_USART1        7
#define GPIO_AF_USART2        7
#define GPIO_AF_USART3        7
#define GPIO_AF_I2S3EXT       7
#define GPIO_AF_UART4         8
#define GPIO_AF_UART5         8
#define GPIO_AF_USART6        8
#define GPIO_AF_CAN1          9
#define GPIO_AF_CAN2          9
#define GPIO_AF_TIM12         9
#define GPIO_AF_TIM13         9
#define GPIO_AF_TIM14         9
#define GPIO_AF_OTGFS1        10
#define GPIO_AF_OTGHS         10
#define GPIO_AF_ETH           11
#define GPIO_AF_FSMC          12
#define GPIO_AF_SDIO          12
#define GPIO_AF_OTGFS2        12
#define GPIO_AF_DCMI          13
#define GPIO_AF_AF14          14
#define GPIO_AF_EVENTOUT      15

/**
 * @brief Function sets GPIO pin alternative function.
 *
 * @param gpio                         Port to set.
 * @param pin                          Pin to set.
 * @param conf                         Alternative function to set.
 */
void gpio_af_config(GPIO_TypeDef * gpio, int32_t pin, int32_t conf);

#endif /* GPIO_F4_H_ */
