#include "tb6612_motor_driver.h"
#include "gpio_f4/gpio_f4.h"

#define TIM2_CH1_PIN				1
#define CH1_IN1_PIN					3
#define CH1_IN2_PIN					2
#define STBY_PIN					1

static void gpio_init(void);
static void timer_init(void);

static void gpio_init(void)
{
	RCC->AHB1ENR |= RCC_AHB1ENR_GPIOAEN;
	RCC->AHB1ENR |= RCC_AHB1ENR_GPIOCEN;

	/*
	 * PA1 - TIM2_CH1
	 */

	gpio_mode_config(GPIOA, TIM2_CH1_PIN, GPIO_MODE_AF);
	gpio_af_config(GPIOA, TIM2_CH1_PIN, GPIO_AF_TIM2);

	/*
	 * PC2 - CH1_IN2
	 * PC3 - CH1_IN1
	 */
	gpio_mode_config(GPIOC, CH1_IN1_PIN, GPIO_MODE_OUTPUT);
	gpio_mode_config(GPIOC, CH1_IN2_PIN, GPIO_MODE_OUTPUT);

	/*
	 * PC1 - STBY
	 */
	gpio_mode_config(GPIOC, STBY_PIN, GPIO_MODE_OUTPUT);

	/*
	 * Init state:
	 * STBY - H
	 * CH1 - L
	 */
	GPIOC->ODR &= ~((1 << CH1_IN1_PIN) | (1 << CH1_IN2_PIN) | (1 << STBY_PIN));
	GPIOC->ODR |= 1 << STBY_PIN;
}

static void timer_init(void)
{
	   RCC->APB1ENR |= RCC_APB1ENR_TIM2EN;

	   TIM2->CR1 = TIM_CR1_CMS_0 | TIM_CR1_CMS_1;	/* Center aligned mode 3	*/
	   TIM2->CCMR1 = TIM_CCMR1_OC2M_2 | TIM_CCMR1_OC2M_1;	/* Channel 2		*/
	   TIM2->CCER = TIM_CCER_CC2E;							/* Output 2 enabled	*/

	   /* Single timer tick is 1us, full cycle is 100us */
	   TIM2->PSC = APB1_CLOCK_FREQ / 1000000 - 1;
	   TIM2->ARR = 100;

	   /* Enable timer */
	   TIM2->CR1 |= TIM_CR1_CEN;
}

void tb6612_init(void)
{
	gpio_init();
	timer_init();
}

void tb6612_motor_1_speed_set(int32_t speed)
{
	TIM2->CCR2 = speed;
}

void tb6612_standby_low(void)
{
	GPIOC->BSRRH = 1 << STBY_PIN;
}

void tb6612_standby_high(void)
{
	GPIOC->BSRRL = 1 << STBY_PIN;
}

void tb6612_motor_1_forward(void)
{
	GPIOC->BSRRH = 1 << CH1_IN1_PIN;
	GPIOC->BSRRL = 1 << CH1_IN2_PIN;
}

void tb6612_motor_1_backward(void)
{
	GPIOC->BSRRL = 1 << CH1_IN1_PIN;
	GPIOC->BSRRH = 1 << CH1_IN2_PIN;
}

void tb6612_motor_1_stop(void)
{
	GPIOA->BSRRH = 1 << CH1_IN1_PIN;
	GPIOA->BSRRH = 1 << CH1_IN2_PIN;
}
