#include "usart.h"

#include "define/hdr_usart.h"
#include "gpio_f4/gpio_f4.h"

#define USART_BAUD_RATE	115200
#define USART_TX_PIN	2

struct usart_tx
{
	uint8_t *buf;
	int32_t idx;
	int32_t n_bytes;
	void **sem;
};

static struct usart_tx tx_params;

void usart_init(void)
{
   RCC->AHB1ENR |= RCC_AHB1ENR_GPIOAEN;
   gpio_mode_config(GPIOA, USART_TX_PIN, GPIO_MODE_AF);
   gpio_af_config(GPIOA, USART_TX_PIN, GPIO_AF_USART1);

   RCC->APB1ENR |= RCC_APB1ENR_USART2EN;

   USART2->BRR = APB1_CLOCK_FREQ / USART_BAUD_RATE;
   USART2->CR1 = USART_CR1_TE | USART_CR1_UE;
   NVIC_SetPriority(USART2_IRQn, 8);
   NVIC_EnableIRQ(USART2_IRQn);

	rtos_sem_bin_create(tx_params.sem);
	rtos_sem_give(tx_params.sem);
}

void usart_send_buf(uint8_t * buf, int32_t n_bytes)
 {
	/* Wait for last write completition */
	rtos_sem_take(tx_params.sem, portMAX_DELAY);

	/* Set buffer parameters and set TXE interrupt flag */
	tx_params.buf = buf;
	tx_params.idx = 0;
	tx_params.n_bytes = n_bytes;
	USART2_CR1_TXEIE_bb = 1;

	/* Wait for sem to end of transmission */
	rtos_sem_take(tx_params.sem, portMAX_DELAY);
	rtos_sem_give(tx_params.sem);
}

void USART2_IRQHandler(void)
{
	int32_t yield;

	if (USART2_CR1_TXEIE_bb && USART2_SR_TXE_bb)
	{
		USART2->DR = tx_params.buf[tx_params.idx++];

		if (tx_params.idx >= tx_params.n_bytes)
		{
			USART2_CR1_TXEIE_bb = 0;
			USART2_CR1_TCIE_bb = 1;
		}
	}

	if (USART2_CR1_TCIE_bb && USART2_SR_TC_bb)
	{
		USART2_CR1_TCIE_bb = 0;
		rtos_sem_give_isr(tx_params.sem, &yield);
	}

	portYIELD_FROM_ISR(yield);
}
